package com.example;

import java.io.*;
import java.util.Calendar;
import java.text.DecimalFormat;

import javax.swing.*;

import java.awt.Dimension;

import org.jfree.data.time.*;
import org.jfree.chart.*;
import org.jfree.chart.axis.NumberAxis;
import org.jfree.chart.plot.XYPlot;
import org.jfree.chart.renderer.xy.XYBarRenderer;
import org.jfree.chart.util.ExportUtils;
import org.jfree.data.xy.IntervalXYDataset;
import org.jfree.data.xy.XYDataset;

public class SVGExport extends JFrame
{
	private static final long serialVersionUID = 1L;
	
	private static double        previousVolume = 41000D;
    private static final double  volumeRange = 50000D;
    private static final int     numdays = 100;
    private static double        previousPrice = 98D;
    private static final double  priceRange = 1D;


    private JFreeChart jfreechart;

	public SVGExport()
	{
        setContentPane(createDemoPanel());
        exportChart();
	}
    private void exportChart()
    {
        File file = new File("svg/barChartDemo.svg");
        ExportUtils.writeAsSVG(jfreechart, 500, 270, file);
    }

	private JFreeChart createChart()
	{
		XYDataset xydataset = createPriceDataset();
		jfreechart = ChartFactory.createTimeSeriesChart("Example chart", 
			                    null, "Price", xydataset, true, true, false);
		XYPlot xyplot = jfreechart.getXYPlot();
		NumberAxis numberaxis = (NumberAxis)xyplot.getRangeAxis();
		numberaxis.setLowerMargin(0.40000000000000002D);
		DecimalFormat decimalformat = new DecimalFormat("00.00");
		numberaxis.setNumberFormatOverride(decimalformat);
		NumberAxis numberaxis1 = new NumberAxis("Volume");
		numberaxis1.setUpperMargin(1.0D);
		xyplot.setRangeAxis(1, numberaxis1);
		xyplot.setDataset(1, createVolumeDataset());
		xyplot.setRangeAxis(1, numberaxis1);
		xyplot.mapDatasetToRangeAxis(1, 1);
		XYBarRenderer xybarrenderer = new XYBarRenderer(0.20000000000000001D);
		xyplot.setRenderer(1, xybarrenderer);
		return jfreechart;
	}

	private XYDataset createPriceDataset()
	{
		TimeSeries timeseries = new TimeSeries("Price");
		Calendar today = Calendar.getInstance();
		// go back numdays in time
		today.add(Calendar.DAY_OF_MONTH, -numdays);
	        
		for (int i = 0; i < numdays; i++) {
			timeseries.add(new Day(today.get(Calendar.DAY_OF_MONTH),
					today.get(Calendar.MONTH) + 1,
					today.get(Calendar.YEAR)), randomPrice());
			// increase one day
			today.add(Calendar.DAY_OF_MONTH, 1);
		}
		return new TimeSeriesCollection(timeseries);
    }
	    
	private static IntervalXYDataset createVolumeDataset()
	{
		TimeSeries timeseries = new TimeSeries("Volume");
	        
		Calendar today = Calendar.getInstance();
		// go back numdays in time
		today.add(Calendar.DAY_OF_MONTH, -numdays);
	        
		for (int i = 0; i < numdays; i++) {
			timeseries.add(new Day(
					today.get(Calendar.DAY_OF_MONTH),
					today.get(Calendar.MONTH) + 1,
					today.get(Calendar.YEAR)), randomVolume());
	        	// increase one day
	        	today.add(Calendar.DAY_OF_MONTH, 1);
	        }
		return new TimeSeriesCollection(timeseries);
	}
	private static double randomVolume() {
		previousVolume = (Math.random() - 0.5d) * volumeRange + previousVolume;
		if (previousVolume < 0) 
			previousVolume = 0;
		return previousVolume;
	}
	    
	private static double randomPrice() {
		previousPrice = (Math.random() - 0.5d) * priceRange + previousPrice;
		if (previousPrice < 0) 
			previousPrice = 0;
		return previousPrice;
	}

	public JPanel createDemoPanel()
	{
		createChart();
		ChartPanel chartpanel = new ChartPanel(jfreechart, true, true, true, false, true);
		chartpanel.setPreferredSize(new Dimension(560, 500));
		return chartpanel;
	}

	public static void main(String args[])
	{
		SVGExport demo = new SVGExport();
		demo.pack();
		demo.setVisible(true);
	}
}
